Crate kcr_operator_open_cluster_management_io

Crate kcr_operator_open_cluster_management_io 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the operator.open-cluster-management.io group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

operator.open-cluster-management.io/v1

  • ClusterManager
  • Klusterlet

Modules

v1